Error

Enum Error 

pub enum Error {
Show 14 variants EmptyTimestamp, InvalidTimestamp, EmptyEndpoint, EmptyGingrEndpoint, EmptyRecordId, EmptyProviderRecordId, EmptyExtractionBatch, EmptyRequestScope, EmptySchemaVersion, EmptyProviderSchemaVersion, EmptyPayloadHash, EmptyRawPayloadRef, EmptyObservedStatus, EmptyProviderStatus,
}
Validation failures returned by source domain constructors.

Variants



EmptyTimestamp

Signals that timestamp was blank or missing during source validation.



InvalidTimestamp

Signals that timestamp could not be parsed or accepted during source validation.



EmptyEndpoint

Signals that endpoint was blank or missing during source validation.



EmptyGingrEndpoint

Signals that gingr endpoint was blank or missing during source validation.



EmptyRecordId

Signals that record id was blank or missing during source validation.



EmptyProviderRecordId

Signals that provider record id was blank or missing during source validation.



EmptyExtractionBatch

Signals that extraction batch was blank or missing during source validation.



EmptyRequestScope

Signals that request scope was blank or missing during source validation.



EmptySchemaVersion

Signals that schema version was blank or missing during source validation.



EmptyProviderSchemaVersion

Signals that provider schema version was blank or missing during source validation.



EmptyPayloadHash

Signals that payload hash was blank or missing during source validation.



EmptyRawPayloadRef

Signals that raw payload ref was blank or missing during source validation.



EmptyObservedStatus

Signals that observed status was blank or missing during source validation.



EmptyProviderStatus

Signals that provider status was blank or missing during source validation.