pub struct Provenance { /* private fields */ }Expand description
Lineage metadata that ties normalized data back to its provider record.
Implementations
Sourceimpl Provenance
impl Provenance
Sourcepub fn builder() -> ProvenanceBuilder
pub fn builder() -> ProvenanceBuilder
Create an instance of Provenance using the builder syntax
Sourceimpl Provenance
impl Provenance
Sourcepub const fn system(&self) -> System
pub const fn system(&self) -> System
Returns the system evidence carried by this source-lineage value.
Sourcepub const fn source_system(&self) -> System
pub const fn source_system(&self) -> System
Returns the source system evidence carried by this source-lineage value.
Sourcepub const fn endpoint(&self) -> &Endpoint
pub const fn endpoint(&self) -> &Endpoint
Returns the endpoint evidence carried by this source-lineage value.
Sourcepub const fn record_id(&self) -> &Id
pub const fn record_id(&self) -> &Id
Returns the record id evidence carried by this source-lineage value.
Returns the related record ids evidence carried by this source snapshot.
Sourcepub const fn extraction_batch(&self) -> &ExtractionBatchId
pub const fn extraction_batch(&self) -> &ExtractionBatchId
Returns the extraction batch evidence carried by this source-lineage value.
Sourcepub const fn pulled_at(&self) -> &Timestamp
pub const fn pulled_at(&self) -> &Timestamp
Returns the pulled at evidence carried by this source-lineage value.
Sourcepub const fn request_scope(&self) -> &RequestScope
pub const fn request_scope(&self) -> &RequestScope
Returns the request scope evidence carried by this source-lineage value.
Sourcepub const fn schema_version(&self) -> &SchemaVersion
pub const fn schema_version(&self) -> &SchemaVersion
Returns the schema version evidence carried by this source-lineage value.
Sourcepub const fn payload_hash(&self) -> &PayloadHash
pub const fn payload_hash(&self) -> &PayloadHash
Returns the payload hash evidence carried by this source-lineage value.
Sourcepub const fn raw_payload_ref(&self) -> &RawPayloadRef
pub const fn raw_payload_ref(&self) -> &RawPayloadRef
Returns the raw payload ref evidence carried by this source-lineage value.